==> tensorflow-datasets-4.5.0.tar.gz: tensorflow-datasets-4.5.0/tensorflow_datasets/translate/__init__.py <==
# coding=utf-8
# Copyright 2022 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Translation datasets."""

from tensorflow_datasets.translate.flores import Flores
from tensorflow_datasets.translate.flores import FloresConfig
from tensorflow_datasets.translate.opus import Opus
from tensorflow_datasets.translate.para_crawl import ParaCrawl
from tensorflow_datasets.translate.para_crawl import ParaCrawlConfig
from tensorflow_datasets.translate.ted_hrlr import TedHrlrTranslate
from tensorflow_datasets.translate.ted_multi import TedMultiTranslate
from tensorflow_datasets.translate.wmt import WmtConfig
from tensorflow_datasets.translate.wmt13 import Wmt13Translate
from tensorflow_datasets.translate.wmt14 import Wmt14Translate
from tensorflow_datasets.translate.wmt15 import Wmt15Translate
from tensorflow_datasets.translate.wmt16 import Wmt16Translate
from tensorflow_datasets.translate.wmt17 import Wmt17Translate
from tensorflow_datasets.translate.wmt18 import Wmt18Translate
from tensorflow_datasets.translate.wmt19 import Wmt19Translate
from tensorflow_datasets.translate.wmt_t2t import WmtT2tTranslate

==> tensorflow-datasets-4.7.0.tar.gz: tensorflow-datasets-4.7.0/tensorflow_datasets/translate/__init__.py <==
# coding=utf-8
# Copyright 2022 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Translation datasets."""

from tensorflow_datasets.translate.bucc import Bucc
from tensorflow_datasets.translate.flores import Flores
from tensorflow_datasets.translate.flores import FloresConfig
from tensorflow_datasets.translate.mtnt import Mtnt
from tensorflow_datasets.translate.opus import Opus
from tensorflow_datasets.translate.para_crawl import ParaCrawl
from tensorflow_datasets.translate.para_crawl import ParaCrawlConfig
from tensorflow_datasets.translate.tatoeba import Tatoeba
from tensorflow_datasets.translate.ted_hrlr import TedHrlrTranslate
from tensorflow_datasets.translate.ted_multi import TedMultiTranslate
from tensorflow_datasets.translate.wmt import WmtConfig
from tensorflow_datasets.translate.wmt13 import Wmt13Translate
from tensorflow_datasets.translate.wmt14 import Wmt14Translate
from tensorflow_datasets.translate.wmt15 import Wmt15Translate
from tensorflow_datasets.translate.wmt16 import Wmt16Translate
from tensorflow_datasets.translate.wmt17 import Wmt17Translate
from tensorflow_datasets.translate.wmt18 import Wmt18Translate
from tensorflow_datasets.translate.wmt19 import Wmt19Translate
from tensorflow_datasets.translate.wmt_t2t import WmtT2tTranslate
